<?php
/**
 * Add header button element settings.
 *
 * @package Verve Blog
 */

$fields = [
    'header_date_time_group_fields' => [
        'type'              => 'group-field',
        'section'           => 'header_date_time_element_section',
        'priority'          => 5,
        'tabs'              => [
            'desktop'            => [
                'nicename'      => esc_html__( '&gt; 1200px', 'verve-blog' ),
                'preview'       => 'desktop',
                'active_tab'    => true,
                'controls'      => [
                    'header_date_time_sep_1',
                    'header_date_enable',
                    'header_time_enable',
                    'header_time_format',
                    'header_date_time_sep_2',
                    'header_date_time_container_padding',
                    'header_date_time_container_margin'  
                ]
            ],
            'tablet'            => [
                'nicename'      => esc_html__( '&gt; 768px', 'verve-blog' ),
                'preview'       => 'tablet',
                'active_tab'    => false,
                'controls'      => [
                    'header_date_time_sep_2',
                    'header_date_time_container_md_padding',
                    'header_date_time_container_md_margin'

                ]
            ],
            'mobile'            => [
                'nicename'      => esc_html__( '&lt; 576px', 'verve-blog' ),
                'preview'       => 'mobile',
                'active_tab'    => false,
                'controls'      => [
                    'header_date_time_sep_2',
                    'header_date_time_container_sm_padding',
                    'header_date_time_container_sm_margin'
                ]
            ]
        ],
    ],
    'header_date_time_sep_1' => [
        'type'              => 'custom',
        'section'           => 'header_date_time_element_section',
        'default'           => '<h3 style="border-width:1px 0;border-style: solid;border-color: #fff;margin:0 -11px;padding: 8px 12px;background: #fff;">' . esc_html__( 'CONTENT', 'verve-blog' ) . '</h3>',
        'priority'          => 10
    ],
    'header_date_enable' => [
        'type'              => 'toggle',
        'label'             => esc_html__( 'Enable Date', 'verve-blog' ),
        'description'       => esc_html__( 'Toggle to enable/disable date only.', 'verve-blog' ),
        'section'           => 'header_date_time_element_section',
        'default'           => '1',
        'priority'          => 10,
        'partial_refresh'    => [
            'header_date_enable' => [
                'selector'        => '.site-header',
                'render_callback' => 'verve_blog_header_main',
            ],
        ],
    ],
    'header_time_enable' => [
        'type'              => 'toggle',
        'label'             => esc_html__( 'Enable Time', 'verve-blog' ),
        'description'       => esc_html__( 'Toggle to enable/disable time only.', 'verve-blog' ),
        'section'           => 'header_date_time_element_section',
        'default'           => '0',
        'priority'          => 10,
        'partial_refresh'    => [
            'header_time_enable' => [
                'selector'        => '.site-header',
                'render_callback' => 'verve_blog_header_main',
            ],
        ],
    ],
    'header_time_format' => [
        'type'              => 'radio',
        'label'             => esc_html__( 'Time Format', 'verve-blog' ),
        'section'           => 'header_date_time_element_section',
        'default'           => 'en-US',
        'priority'          => 10,
        'choices'           => [
            'en-US' => esc_html__( 'Theme Default Setting', 'verve-blog' ),
            'en-WP' => esc_html__( 'From WordPress Setting', 'verve-blog' )
        ],
        'partial_refresh'    => [
            'header_time_format' => [
                'selector'        => '.site-header',
                'render_callback' => 'verve_blog_header_main',
            ],
        ],
    ],
    'header_date_time_sep_2' => [
        'type'              => 'custom',
        'section'           => 'header_date_time_element_section',
        'default'           => '<h3 style="border-width:1px 0;border-style: solid;border-color: #fff;margin:0 -11px;padding: 8px 12px;background: #fff;">' . esc_html__( 'CONTAINER SETTING', 'verve-blog' ) . '</h3>',
        'priority'          => 10
    ],
    'header_date_time_container_padding' => [
        'type'        => 'dimensions',
        'label'       => esc_html__( 'Padding', 'verve-blog' ),
        'description' => esc_html__( 'Set date & time container padding.', 'verve-blog' ),
        'section'     => 'header_date_time_element_section',
        'priority'    => 10,
        'default'     => [
            'padding-top'    => '',
            'padding-bottom' => '',
            'padding-left'   => '',
            'padding-right'  => '',
        ],
        'choices'     => [
            'labels'    => [
                'padding-top'    => esc_html__( 'Top', 'verve-blog' ),
                'padding-bottom' => esc_html__( 'Bottom', 'verve-blog' ),
                'padding-left'   => esc_html__( 'Left', 'verve-blog' ),
                'padding-right'  => esc_html__( 'Right', 'verve-blog' ),
            ],
        ],
        'transport'         => 'auto',
        'output'            => [
            [
                'choice'    => 'padding-top',
                'property'  => 'padding-top',
                'element'   => '.site-header .header-data-time-wrap',
            ],
            [
                'choice'    => 'padding-bottom',
                'property'  => 'padding-bottom',
                'element'   => '.site-header .header-data-time-wrap',
            ],
            [
                'choice'    => 'padding-left',
                'property'  => 'padding-left',
                'element'   => '.site-header .header-data-time-wrap',
            ],
            [
                'choice'    => 'padding-right',
                'property'  => 'padding-right',
                'element'   => '.site-header .header-data-time-wrap',
            ],
        ],
    ],
    'header_date_time_container_md_padding' => [
        'type'        => 'dimensions',
        'label'       => esc_html__( 'Padding', 'verve-blog' ),
        'description' => esc_html__( 'Set date & time container padding.', 'verve-blog' ),
        'section'     => 'header_date_time_element_section',
        'priority'    => 10,
        'default'     => [
            'padding-top'    => '',
            'padding-bottom' => '',
            'padding-left'   => '',
            'padding-right'  => '',
        ],
        'choices'     => [
            'labels'    => [
                'padding-top'    => esc_html__( 'Top', 'verve-blog' ),
                'padding-bottom' => esc_html__( 'Bottom', 'verve-blog' ),
                'padding-left'   => esc_html__( 'Left', 'verve-blog' ),
                'padding-right'  => esc_html__( 'Right', 'verve-blog' ),
            ],
        ],
        'transport'         => 'auto',
        'output'            => [
            [
                'media_query'   => '@media (max-width: 768px)',
                'choice'        => 'padding-top',
                'property'      => 'padding-top',
                'element'       => '.site-header .header-data-time-wrap',
            ],
            [
                'media_query'   => '@media (max-width: 768px)',
                'choice'        => 'padding-bottom',
                'property'      => 'padding-bottom',
                'element'       => '.site-header .header-data-time-wrap',
            ],
            [
                'media_query'   => '@media (max-width: 768px)',
                'choice'        => 'padding-left',
                'property'      => 'padding-left',
                'element'       => '.site-header .header-data-time-wrap',
            ],
            [
                'media_query'   => '@media (max-width: 768px)',
                'choice'        => 'padding-right',
                'property'      => 'padding-right',
                'element'       => '.site-header .header-data-time-wrap',
            ],
        ],
    ],
    'header_date_time_container_sm_padding' => [
        'type'        => 'dimensions',
        'label'       => esc_html__( 'Padding', 'verve-blog' ),
        'description' => esc_html__( 'Set date & time container padding.', 'verve-blog' ),
        'section'     => 'header_date_time_element_section',
        'priority'    => 10,
        'default'     => [
            'padding-top'    => '',
            'padding-bottom' => '',
            'padding-left'   => '',
            'padding-right'  => '',
        ],
        'choices'     => [
            'labels'    => [
                'padding-top'    => esc_html__( 'Top', 'verve-blog' ),
                'padding-bottom' => esc_html__( 'Bottom', 'verve-blog' ),
                'padding-left'   => esc_html__( 'Left', 'verve-blog' ),
                'padding-right'  => esc_html__( 'Right', 'verve-blog' ),
            ],
        ],
        'transport'         => 'auto',
        'output'            => [
            [
                'media_query'   => '@media (max-width: 576px)',
                'choice'        => 'padding-top',
                'property'      => 'padding-top',
                'element'       => '.site-header .header-data-time-wrap',
            ],
            [
                'media_query'   => '@media (max-width: 576px)',
                'choice'        => 'padding-bottom',
                'property'      => 'padding-bottom',
                'element'       => '.site-header .header-data-time-wrap',
            ],
            [
                'media_query'   => '@media (max-width: 576px)',
                'choice'        => 'padding-left',
                'property'      => 'padding-left',
                'element'       => '.site-header .header-data-time-wrap',
            ],
            [
                'media_query'   => '@media (max-width: 576px)',
                'choice'        => 'padding-right',
                'property'      => 'padding-right',
                'element'       => '.site-header .header-data-time-wrap',
            ],
        ],
    ],
    'header_date_time_container_margin' => [
        'type'        => 'dimensions',
        'label'       => esc_html__( 'Margin', 'verve-blog' ),
        'description' => esc_html__( 'Set date & time container margin.', 'verve-blog' ),
        'section'     => 'header_date_time_element_section',
        'priority'    => 10,
        'default'     => [
            'margin-top'    => '',
            'margin-bottom' => '',
            'margin-left'   => '',
            'margin-right'  => '',
        ],
        'choices'     => [
            'labels'    => [
                'margin-top'    => esc_html__( 'Top', 'verve-blog' ),
                'margin-bottom' => esc_html__( 'Bottom', 'verve-blog' ),
                'margin-left'   => esc_html__( 'Left', 'verve-blog' ),
                'margin-right'  => esc_html__( 'Right', 'verve-blog' ),
            ],
        ],
        'transport'         => 'auto',
        'output'            => [
            [
                'choice'    => 'margin-top',
                'property'  => 'margin-top',
                'element'   => '.site-header .header-data-time-wrap',
            ],
            [
                'choice'    => 'margin-bottom',
                'property'  => 'margin-bottom',
                'element'   => '.site-header .header-data-time-wrap',
            ],
            [
                'choice'    => 'margin-left',
                'property'  => 'margin-left',
                'element'   => '.site-header .header-data-time-wrap',
            ],
            [
                'choice'    => 'margin-right',
                'property'  => 'margin-right',
                'element'   => '.site-header .header-data-time-wrap',
            ],
        ],
    ],
    'header_date_time_container_md_margin' => [
        'type'        => 'dimensions',
        'label'       => esc_html__( 'Margin', 'verve-blog' ),
        'description' => esc_html__( 'Set date & time container margin.', 'verve-blog' ),
        'section'     => 'header_date_time_element_section',
        'priority'    => 10,
        'default'     => [
            'margin-top'    => '',
            'margin-bottom' => '',
            'margin-left'   => '',
            'margin-right'  => '',
        ],
        'choices'     => [
            'labels'    => [
                'margin-top'    => esc_html__( 'Top', 'verve-blog' ),
                'margin-bottom' => esc_html__( 'Bottom', 'verve-blog' ),
                'margin-left'   => esc_html__( 'Left', 'verve-blog' ),
                'margin-right'  => esc_html__( 'Right', 'verve-blog' ),
            ],
        ],
        'transport'         => 'auto',
        'output'            => [
            [
                'media_query'   => '@media (max-width: 768px)',
                'choice'        => 'margin-top',
                'property'      => 'margin-top',
                'element'       => '.site-header .header-data-time-wrap',
            ],
            [
                'media_query'   => '@media (max-width: 768px)',
                'choice'        => 'margin-bottom',
                'property'      => 'margin-bottom',
                'element'       => '.site-header .header-data-time-wrap',
            ],
            [
                'media_query'   => '@media (max-width: 768px)',
                'choice'        => 'margin-left',
                'property'      => 'margin-left',
                'element'       => '.site-header .header-data-time-wrap',
            ],
            [
                'media_query'   => '@media (max-width: 768px)',
                'choice'        => 'margin-right',
                'property'      => 'margin-right',
                'element'       => '.site-header .header-data-time-wrap',
            ],
        ],
    ],
    'header_date_time_container_sm_margin' => [
        'type'        => 'dimensions',
        'label'       => esc_html__( 'Margin', 'verve-blog' ),
        'description' => esc_html__( 'Set date & time container margin.', 'verve-blog' ),
        'section'     => 'header_date_time_element_section',
        'priority'    => 10,
        'default'     => [
            'margin-top'    => '',
            'margin-bottom' => '',
            'margin-left'   => '',
            'margin-right'  => '',
        ],
        'choices'     => [
            'labels'    => [
                'margin-top'    => esc_html__( 'Top', 'verve-blog' ),
                'margin-bottom' => esc_html__( 'Bottom', 'verve-blog' ),
                'margin-left'   => esc_html__( 'Left', 'verve-blog' ),
                'margin-right'  => esc_html__( 'Right', 'verve-blog' ),
            ],
        ],
        'transport'         => 'auto',
        'output'            => [
            [
                'media_query'   => '@media (max-width: 576px)',
                'choice'        => 'margin-top',
                'property'      => 'margin-top',
                'element'       => '.site-header .header-data-time-wrap',
            ],
            [
                'media_query'   => '@media (max-width: 576px)',
                'choice'        => 'margin-bottom',
                'property'      => 'margin-bottom',
                'element'       => '.site-header .header-data-time-wrap',
            ],
            [
                'media_query'   => '@media (max-width: 576px)',
                'choice'        => 'margin-left',
                'property'      => 'margin-left',
                'element'       => '.site-header .header-data-time-wrap',
            ],
            [
                'media_query'   => '@media (max-width: 576px)',
                'choice'        => 'margin-right',
                'property'      => 'margin-right',
                'element'       => '.site-header .header-data-time-wrap',
            ],
        ],
    ],
];
foreach ( $fields as $field_id => $field_args ) {
    // Settings
    $field_args['settings'] = str_replace( '-', '_', $field_id );

    Kirki::add_field( 'verve-blog', $field_args );
}